@@ -1,5 +1,5 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.32';
+$App::pherkin::VERSION = '0.33';
 use strict;
 use warnings;
 
@@ -17,13 +17,15 @@ use Moose;
 has 'tags'       => ( is => 'rw', isa => 'ArrayRef', required => 0 );
 has 'tag_scheme' => ( is => 'rw', isa => 'ArrayRef', required => 0 );
 
+has 'harness'    => ( is => 'rw' );
+
 =head1 NAME
 
 App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -59,14 +61,21 @@ sub run {
  # localized features will have utf8 in them and options may output utf8 as well
     binmode STDOUT, ':utf8';
 
-    my ( $options, @feature_files ) = $self->_process_arguments(@arguments);
+    my ( $features_path ) = $self->_process_arguments(@arguments);
+    $features_path ||= './features/';
 
-    my $features_path = $feature_files[0] || './features/';
     my ( $executor, @features ) =
       Test::BDD::Cucumber::Loader->load( $features_path, $self->tag_scheme );
     die "No feature files found in $features_path" unless @features;
 
-    my $harness = $self->_load_harness( $options->{'harness'} );
+    return $self->_run_tests($executor, @features);
+}
+
+sub _run_tests {
+    my ( $self, $executor, @features ) = @_;
+
+    my $harness = $self->harness;
+    $harness->startup();
 
     my $tag_spec;
     if ( $self->tag_scheme ) {
@@ -80,7 +89,7 @@ sub run {
     return $harness->result;
 }
 
-sub _load_harness {
+sub _initialize_harness {
     my ( $self, $harness_module ) = @_;
 
     unless ( $harness_module =~ m/::/ ) {
@@ -90,10 +99,7 @@ sub _load_harness {
     eval { use_module($harness_module) }
       || die "Unable to load harness [$harness_module]: $@";
 
-    my $harness = $harness_module->new();
-    $harness->startup();
-
-    return $harness;
+    $self->harness( $harness_module->new() );
 }
 
 sub _process_arguments {
@@ -130,14 +136,14 @@ sub _process_arguments {
     unshift @$includes, 'blib/lib', 'blib/arch' if $add_blib;
 
     # Munge the output harness
-    $harness = "TermColor" unless defined $harness;
+    $self->_initialize_harness($harness || "TermColor");
 
     lib->import(@$includes) if @$includes;
 
     # Store our TagSpecScheme
     $self->tag_scheme( $self->_process_tags( @{$tags} ) );
 
-    return ( { harness => $harness }, pop @ARGV );
+    return ( pop @ARGV );
 }
 
 sub _process_tags {
