@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness::JSON;
-$Test::BDD::Cucumber::Harness::JSON::VERSION = '0.32';
+$Test::BDD::Cucumber::Harness::JSON::VERSION = '0.33';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::JSON - Generate results to JSON file
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
@@ -108,7 +108,7 @@ sub format_feature {
     return {
         uri         => $feature->name_line->filename,
         keyword     => $self->get_keyword( $feature->name_line ),
-        id          => "feature-" . int($feature),
+        id          => $self->_generate_stable_id( $feature->name_line ),
         name        => $feature->name,
         line        => $feature->name_line->number,
         description => $self->format_description($feature),
@@ -121,7 +121,7 @@ sub format_scenario {
     my ( $self, $scenario, $dataset ) = @_;
     return {
         keyword => $self->get_keyword( $scenario->line ),
-        id      => "scenario-" . int($scenario),
+        id      => $self->_generate_stable_id( $scenario->line ),
         name    => $scenario->name,
         line    => $scenario->line->number,
         tags    => $self->format_tags( $scenario->tags ),
@@ -130,6 +130,11 @@ sub format_scenario {
     };
 }
 
+sub _generate_stable_id {
+    my ( $self, $line ) = @_;
+    return $line->filename . ":" . $line->number;
+}
+
 sub format_step {
     my ( $self, $step_context, $result, $duration ) = @_;
     my $step = $step_context->step;
